@@ -16,6 +16,7 @@ from pytorch_grad_cam import GuidedBackpropReLUModel
 from pytorch_grad_cam.utils.image import show_cam_on_image, \
     deprocess_image, \
     preprocess_image
+from pytorch_grad_cam.utils.model_targets import ClassifierOutputTarget
 
 
 def get_args():
@@ -77,7 +78,7 @@ if __name__ == '__main__':
     # Choose the target layer you want to compute the visualization for.
     # Usually this will be the last convolutional layer in the model.
     # Some common choices can be:
-    # Resnet18 and 50: model.layer4[-1]
+    # Resnet18 and 50: model.layer4
     # VGG, densenet161: model.features[-1]
     # mnasnet1_0: model.layers[-1]
     # You can print the model to help chose the layer
@@ -86,7 +87,7 @@ if __name__ == '__main__':
     # You can also try selecting all layers of a certain type, with e.g:
     # from pytorch_grad_cam.utils.find_layers import find_layer_types_recursive
     # find_layer_types_recursive(model, [torch.nn.ReLU])
-    target_layers = [model.layer4[-1]]
+    target_layers = [model.layer4]
 
     rgb_img = cv2.imread(args.image_path, 1)[:, :, ::-1]
     rgb_img = np.float32(rgb_img) / 255
@@ -94,9 +95,13 @@ if __name__ == '__main__':
                                     mean=[0.485, 0.456, 0.406],
                                     std=[0.229, 0.224, 0.225])
 
-    # If None, returns the map for the highest scoring category.
-    # Otherwise, targets the requested category.
-    target_category = None
+
+    # We have to specify the target we want to generate
+    # the Class Activation Maps for.
+    # If targets is None, the highest scoring category (for every member in the batch) will be used.
+    # You can target specific categories by
+    # targets = [e.g ClassifierOutputTarget(281)]
+    targets = None
 
     # Using the with statement ensures the context is freed, and you can
     # recreate different CAM objects in a loop.
@@ -108,9 +113,8 @@ if __name__ == '__main__':
         # AblationCAM and ScoreCAM have batched implementations.
         # You can override the internal batch size for faster computation.
         cam.batch_size = 32
-
         grayscale_cam = cam(input_tensor=input_tensor,
-                            target_category=target_category,
+                            targets=targets,
                             aug_smooth=args.aug_smooth,
                             eigen_smooth=args.eigen_smooth)
 
@@ -123,7 +127,7 @@ if __name__ == '__main__':
         cam_image = cv2.cvtColor(cam_image, cv2.COLOR_RGB2BGR)
 
     gb_model = GuidedBackpropReLUModel(model=model, use_cuda=args.use_cuda)
-    gb = gb_model(input_tensor, target_category=target_category)
+    gb = gb_model(input_tensor, target_category=None)
 
     cam_mask = cv2.merge([grayscale_cam, grayscale_cam, grayscale_cam])
     cam_gb = deprocess_image(cam_mask * gb)
